@@ -182,7 +182,7 @@ pkgplan_init_lockfile <- function(self, private, lockfile, config,
 
   pkgs <- raw$packages
   refs <- vcapply(pkgs, "[[", "ref")
-  soldata <- tibble(
+  soldata <- data_frame(
     ref              = refs,
     type             = vcapply(pkgs, "[[", "type"),
     direct           = vlapply(pkgs, "[[", "direct"),
@@ -190,7 +190,7 @@ pkgplan_init_lockfile <- function(self, private, lockfile, config,
     status           = "OK",
     package          = vcapply(pkgs, "[[", "package"),
     version          = vcapply(pkgs, "[[", "version"),
-    license          = vcapply(pkgs, "[[", "license"),
+    license          = vcapply(pkgs, function(x) x$license %||% NA_character_),
     needscompilation = vlapply(pkgs, function(x) x$needscompilation %||% NA),
     sha256           = vcapply(pkgs, function(x) x$sha256 %||% NA_character_),
     filesize         = viapply(pkgs, function(x) x$filesize %||% NA_integer_),
